# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.contrib.admin.sites import NotRegistered
from django.utils.translation import ugettext_lazy as _


if 'django.contrib.flatpages' in settings.INSTALLED_APPS:
    from django.contrib.flatpages.models import FlatPage
    from .adminforms import FlatpageForm

    class FlatPageAdmin(admin.ModelAdmin):
        form = FlatpageForm
        fieldsets = (
            (None, {'fields': ('url', 'title', 'content', 'sites')}),
            (_('Advanced options'), {
                'classes': ('collapse',), 'fields': (
                    'enable_comments', 'registration_required', 'template_name')
            }),
        )
        list_display = ('url', 'title')
        list_filter = ('sites', 'enable_comments', 'registration_required')
        search_fields = ('url', 'title')
        filter_horizontal = ['sites']

    try:
        admin.site.unregister(FlatPage)
    except NotRegistered:
        pass
    admin.site.register(FlatPage, FlatPageAdmin)
