# -*- coding: utf-8 -*-

from django.apps import apps
from django.apps import AppConfig
from django.db import transaction, DatabaseError
from django.db.models.signals import post_migrate
from django.core.exceptions import ObjectDoesNotExist
from django.core.exceptions import AppRegistryNotReady


def autocreate(sender, **kwargs):
    from django.contrib.sites.models import Site
    from django.contrib.flatpages.models import FlatPage

    from django.contrib.webdesign.lorem_ipsum import paragraphs

    from about.settings import (
        AUTOCREATE, DEFAULT_URL, DEFAULT_TITLE, PAGES)

    def create_flatpage(title, url):
        current_site = Site.objects.get_current()

        page, created = FlatPage.objects.get_or_create(url=url.lower())
        page.sites.add(current_site)

        if created is True:  # feel page with a random text
            page.title, page.content = title, paragraphs(1, common=True)[0]
            page.save()

        return page

    if AUTOCREATE is True:
        try:
            with transaction.atomic():
                # create default about page
                create_flatpage(DEFAULT_TITLE, DEFAULT_URL)

                # create pre-defined pages...
                for slug, title in PAGES.items():
                    create_flatpage(title, '%s%s/' % (DEFAULT_URL, slug))

        except (DatabaseError, ObjectDoesNotExist, AppRegistryNotReady):
            pass  # shit happens

    post_migrate.connect(autocreate, sender=FlatPage)


class AboutConfig(AppConfig):
    label = name = 'about'

    def ready(self):
        post_migrate.connect(
            autocreate, sender=apps.get_app_config('flatpages'))
